@@ -17,9 +17,9 @@ use English qw/ -no_match_vars /;
 use Data::Context::BEM::Instance;
 use Template;
 use File::ShareDir qw/module_dir dist_dir/;
-use Path::Class;
+use Path::Tiny;
 
-our $VERSION = version->new('0.0.4');
+our $VERSION = version->new('0.0.5');
 
 extends 'Data::Context';
 
@@ -132,7 +132,7 @@ sub get_styles {
     for my $block ( keys %$blocks ) {
         for my $path (@$paths) {
             if ( -s "$path/blocks/$block/block.css" ) {
-                push @css, file "$path/blocks/$block/block.css";
+                push @css, path("$path/blocks/$block/block.css");
                 next BLOCK;
             }
         }
@@ -162,7 +162,7 @@ sub get_scripts {
     for my $block ( keys %$blocks ) {
         for my $path (@$paths) {
             if ( -s "$path/blocks/$block/block.js" ) {
-                push @js, file "$path/blocks/$block/block.js";
+                push @js, path("$path/blocks/$block/block.js");
                 next BLOCK;
             }
         }
@@ -272,7 +272,7 @@ Data::Context::BEM - A Perl implementation of BEM
 
 =head1 VERSION
 
-This documentation refers to Data::Context::BEM version 0.0.4
+This documentation refers to Data::Context::BEM version 0.0.5
 
 =head1 SYNOPSIS
 
